#
# spec file for package font-manager
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global DBusName com.github.FontManager.FontManager
%global DBusName2 com.github.FontManager.FontViewer
Name:           font-manager
Version:        0.9.2
Release:        1.3
Summary:        A simple font management application for Gtk+ Desktop Environments
License:        GPL-3.0-or-later
URL:            https://fontmanager.github.io
Source0:        https://github.com/FontManager/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  appstream-glib
BuildRequires:  gettext-runtime
BuildRequires:  meson >= 0.59
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.56
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2) >= 2.10
BuildRequires:  pkgconfig(glib-2.0) >= 2.62
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk4) >= 4.12
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.5
BuildRequires:  pkgconfig(libnautilus-extension-4)
BuildRequires:  pkgconfig(libnemo-extension)
BuildRequires:  pkgconfig(libsoup-3.0) >= 3.2
BuildRequires:  pkgconfig(libxml-2.0) >= 2.9.10
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(sqlite3) >= 3.35
BuildRequires:  pkgconfig(thunarx-3)
BuildRequires:  pkgconfig(webkitgtk-6.0) >= 2.4
Requires:       %{name}-common
Requires:       font-viewer
Requires:       fontconfig
Requires:       webkitgtk-6_0-injected-bundles

%description
Font Manager is intended to provide a way for average users to easily
 manage desktop fonts, without having to resort to command line tools
 or editing configuration files by hand. While designed primarily with
 the Gnome Desktop Environment in mind, it should work well with other
 Gtk+ desktop environments.

Font Manager is NOT a professional-grade font management solution.

%lang_package

%package -n %{name}-common
Summary:        Common files used by font-manager

%description -n %{name}-common
This package contains common files such as libraries.
 These files are required by font-manager and font-viewer.

%package -n font-viewer
Summary:        Full featured font file preview application for GTK+ Desktop Environments
Requires:       %{name}-common >= %{version}

%description -n font-viewer
This package contains the font-viewer component of font-manager.

%package -n nautilus-%{name}
Summary:        Nautilus extension for Font Manager
Requires:       %{name}-common >= %{version}
Requires:       font-viewer >= %{version}

%description -n nautilus-%{name}
This package provides integration with the Nautilus file manager.

%package -n nemo-%{name}
Summary:        Nemo extension for Font Manager
Requires:       %{name}-common >= %{version}
Requires:       font-viewer >= %{version}

%description -n nemo-%{name}
This package provides integration with the Nemo file manager.

%package -n thunar-%{name}
Summary:        Thunar extension for Font Manager
Requires:       %{name}-common >= %{version}
Requires:       font-viewer >= %{version}

%description -n thunar-%{name}
This package provides integration with the Thunar file manager.

%prep
%autosetup -p1

%build
%meson \
  --buildtype=release \
  -Dnautilus=true \
  -Dnemo=true \
  -Dthunar=true \
  -Dreproducible=true
%meson_build

%install
%meson_install
rm %{buildroot}/%{_libdir}/%{name}/libfontmanager.so

%find_lang %{name}
%suse_update_desktop_file -r com.github.FontManager.FontManager Graphics Viewer
%suse_update_desktop_file -r com.github.FontManager.FontViewer Graphics Viewer

%check
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/*.metainfo.xml

%posttrans
%{_bindir}/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

%files
%{_bindir}/%{name}
%{_datadir}/metainfo/%{DBusName}.metainfo.xml
%{_datadir}/applications/%{DBusName}.desktop
%{_datadir}/dbus-1/services/%{DBusName}.service
%{_datadir}/glib-2.0/schemas/%{DBusName}.gschema.xml
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/%{DBusName}.SearchProvider.ini
%{_datadir}/icons/hicolor/scalable/apps/%{DBusName}.svg
%{_mandir}/man1/%{name}.*

%files -n %{name}-common
%license COPYING
%{_libdir}/%{name}

%files lang -f %{name}.lang

%files -n font-viewer
%{_libexecdir}/%{name}/
%{_datadir}/metainfo/%{DBusName2}.metainfo.xml
%{_datadir}/applications/%{DBusName2}.desktop
%{_datadir}/dbus-1/services/%{DBusName2}.service
%{_datadir}/glib-2.0/schemas/%{DBusName2}.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/%{DBusName2}.svg

%files -n nautilus-%{name}
%{_libdir}/nautilus/extensions-4/nautilus-%{name}.so

%files -n nemo-%{name}
%{_libdir}/nemo/extensions-3.0/nemo-%{name}.so

%files -n thunar-%{name}
%{_libdir}/thunarx-3/thunar-%{name}.so

%changelog
* Sun Jan 19 2025 Jan Baier <jbaier@suse.com>
- Update to 0.9.2
  * Address segfault reported on FreeBSD - Closes #395
  * Add StartupWMClass to desktop files to avoid duplicate entry in docks
* Sun Jan 12 2025 Jan Baier <jbaier@suse.com>
- Update to 0.9.1
  * Address segfault caused by missing sources - Closes #405
  * Update Unicode data files to version 16.0
  * Fix GLib Schema loading to ensure newest file gets loaded
  * Fix base dir detection for Google Fonts waterfall preview
  * Add preference to control spacing between lines in waterfall - Issue #399
  * Check for default preview and load localized version instead - Issue #389
  * Set cursor to visible in active preview - Issue #403
  * Ship fallback icons to avoid missing image icons - Issue #373
  * FontList : Increase margin to improve TreeExpander consistency - Issue #373
  * Waterfall Preview : Allow access to waterfall settings from right click menu - Issue #373
  * Collections : More accurate state tracking
  * Unsorted Category : Fix matching
  * Unsorted Category : Prevent possible crash due to access of null object
  * Browse Mode : Save preview tile size - Issue #373
  * Browse Mode : Set Gtk.GridView:max-columns to 36, defaults to 7 - Issue #373
  * Browse Mode : Add tooltip text to controls - Issue #373
  * Browse Mode : Fix preview size not updating with tile size
  * Browse Mode : Restore list option and allow for custom text - Issue #378
  * Google Fonts : link waterfall settings for consistency
  * Google Fonts : Move file management into Font object for improved state tracking
  * Google Fonts : Set margins to match Manage fontlist
  * Dark Theme : Fix light backgrounds in various areas and dialogs
* Fri Jul  5 2024 Jan Baier <jbaier@suse.com>
- Update to 0.9.0
  * Port to GTK 4
  * Change application identifier to com.github.FontManager.FontManager - Issue #319
  * Add build option to enable loading Adwaita stylesheet, disabled by default.
  * Update appdata file, switch to using metainfo.xml extension.
  * Add option to sort collections by name or size - Issue #297
  * Improve search to include variations and partial matches - Issue #316
  * Add editable preview mode to Google Fonts preview pane - Issue #250
  * Double click selected orthography filter to deselect - Issue #332
  * Drop Fonts table every update to avoid missing fonts - Issue #330
  * Track locale and drop database on change to avoid invalid orthographies - Issue #330
  * Ensure property values are always visible - Issue #292
  * Update vendor list
* Thu May 23 2024 Jan Baier <jbaier@suse.com>
- Update to 0.8.9
  * Bumps libsoup version to 3.0 - Issue #343
  * Fix build failures with Vala >= 0.56.17 - Issue #355
  * Fix failure during copy of font files on export
  * Fix reversed order of font substitutions - Issue #351
  * Update Unicode data to version 15.1.0 - Issue #345
  * Don't disable Fontconfig home, avoids warnings from library
- Remove upstreamed 600f498946c3904064b4e4fdf96e5841f6a827e4.patch
* Mon May 20 2024 Jan Baier <jbaier@suse.com>
- Add 600f498946c3904064b4e4fdf96e5841f6a827e4.patch
  * Allow build to proceed with Vala versions >= 0.56.17
* Fri Sep 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Disable pkgconfig(libnautilus-extension) BuildRequires and pass
  nautilus=false to meson, no longer build nautilus support.
  Font-manager needs to be ported to gtk4. See upstream issue:
  https://github.com/FontManager/font-manager/issues/286
- Add obsoletes nautilus-fontmanager to ease upgrades.
* Mon Feb 14 2022 Jan Baier <jbaier@suse.com>
- Update to 0.8.8
  * Fixes build failure with GCC 11 - Issue #240
  * Bumps Fontconfig minimum version to 2.12
  * Adds options for Waterfall display and sizing - Issue #230
  * Enables basic support for Emoji flag sequences - Issue #109
  * Fixes warnings generated when double clicking an item in the fontlist - Issue #248
  * Fixes warnings generated when an unknown language is encountered - Google Fonts Catalog - Issue #249
  * Allows toggling the state of multiple families in the fontlist - Issue #261
  * Updates vendor list
  * Includes latest translation updates
- Remove upstreamed font-manager-fix-gcc11-compilation.patch
* Fri Oct 15 2021 Jan Baier <jbaier@suse.com>
- Add font-manager-fix-gcc11-compilation.patch
  * Add (skip) annotation to fsType_to_string
* Thu Jul 29 2021 Jan Baier <jbaier@suse.com>
- Update to 0.8.7
  * Fixes rendering issues with Pango > 1.47 - Issue #213
  * Fixes missing desktop settings with GNOME 40 - Issue #215
  * Fixes missing substitution target family names - Issue #216
  * Restore font list positions when switching filters and after drag and drop - Issue #220
  * Adds a "rename" entry to collections context menu - Suggested in Issue #220
  * Switches to using symbolic icons in sidebar for consistency
  * Limits Waterfall preview to 48pt to improve application responsiveness with large font collections
  * Adds a preference to allow setting maximum Waterfall preview point size
  * Update vendor list
  * Include latest translation updates
* Fri Jun 25 2021 Jan Baier <jbaier@suse.com>
- Fix source url in spec file
* Sun Jun 13 2021 Jan Baier <jbaier@suse.com>
- Update spec file
  Tue Dec 1 22:44:36 UTC 2020 - Giuseppe Stoduto
- Update to 0.8.6
  * Fix GSettings crash with GNOME 40 due to missing "antialias" setting
  * Fix FTBFS with Vala >= 0.52
  * Fix a bug where most categories fail to load on first run.
  * Move to a more traditional sidebar layout - Issue #59
  * Make insensitive controls more consistent across different areas
  * Fix dbus method signature in file manager extensions
  * Fix infinite loop triggered by listing contents of collections which contain children
  * Save / Restore state for Google Fonts preview pane
  * Fix initial preview text in Font Viewer schema
  * Add all currently selected fonts to comparison when add button is clicked - Issue #170
  * Fixes an issue where if a network connection is not available at startup
  * Google Fonts information will never be updated. Flatpak builds hit this issue
  * everytime. Regular installations can simply restart to work around this bug.
  * Revert change incompatible with older Vala versions
  * Include latest translation updates
  * Make WebKit and libsoup optional - #137
  * Fix issue when building with --buildtype=release - #136
  * Fix GF preview issue due to use of localized values in html - #135 / #138
  * Fix crash when downloading fonts - #151
  * Translation updates and bugfixes thanks to @PF4Public - #144
  * Fix FTBFS with Vala 0.50+ - #134
  * Adds Google Fonts integration - #54
  * Requires WebKitGtk and libsoup
  * Allow saving compare lists contents
  * Add GNOME Shell search provider
  * Update Unicode data to 13.0
  * Update vendor data
  Sun Oct  18 22:44:36 UTC 2020 - Giuseppe Stoduto
- Update to 0.7.9
  * Fixes build failures with Vala 0.50
  * Restore Thunar extension - #94
  * Added Dutch translation - thanks to @Vistaus
  * Closes #48 - Allow users to create custom actions
  * Adds install menu item to extensions
  Mon Jul  27 23:00:36 UTC 2020 - Giuseppe Stoduto
- Update to 0.7.8.
  * Closes #122 - Various changes related to Flatpak packaging.
  * Fix incorrect font being added to comparison - #124
  * Filter out legacy fonts which are no longer suported by newer Pamgo versions.
  * Updates / fixes to translations ( #105, #117 )
  * Build system improvements
  Mon Jul  27 22:55:36 UTC 2020 - Giuseppe Stoduto
- Update to 0.7.7.
  * Fix file manager crash caused by extensions
  Mon Jul  27 22:50:36 UTC 2020 - Giuseppe Stoduto
- Update to 0.7.6.
  * Add search to character map
  * Add zoom window to character map on right click
  * Add fsType information to license pane
  * Add grid view to browse mode
  * Add context info / help to preference panes
  * Display progress during database updates
  * Update unicode data to version 12.0.0
  * Update translations
  * Drop use of Python for file manager extensions
  * Closes Issue # 96
    Fix build failure / crash with newer versions of Vala
  * Closes Issue # 75
    Prefer family and style from name table and properly deal with their encoding
  * Addresses Issue # 99
    Add Import / Export for user data
  * Addresses Issue # 102
    Searches starting with : will filter based on character
  Sun Jul  26 21:30:36 UTC 2020 - Giuseppe Stoduto
- Update to 0.7.5.
  * Require Vala >= 0.42
  * Switch to Meson build system
  * Use GtkBuilder templates as much as possible
  * Fix inoperative desktop font preference controls
  * Add language filter to default categories
* Sun Jan  6 2019 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.7.4.
  * Drop dependency on gucharmap library.
  * Drop dependency on Gee library.
  * Drop Intltool.
  * Determine whether file-roller is available at runtime.
  * Fixed a crash that occurred when non font files were dropped
    onto preview areas.
  * Added filetype to property pane.
  * Added designer/designer url to property pane.
  * Added orthography recognition based on the work done for
    Fontaine by Edward H. Trager.
  * Searches starting with / will filter based on filepath.
  * Added preference pane for Gnome desktop settings.
  * Added GtkShortcutsWindow.
  * Updated vendor list.
  * Added option to enable/disable GTK+ animations.
  * Added font substitution preference pane.
  * Added some help documentation.
  * Character map now only displays those codepoints which are
    present in selected font.
  * Added custom preview entry to Browse mode.
  * Added custom preview entry to Compare mode.
  * Make headerbar area more consistent with other Gtk+ applications.
  * Added "Copy Location" and "Show in Folder" entries to the font
    list context menu.
  * Added "Copy to.." and "Compress..." entries to the collection
    list context menu.
  * Force sidebar content to stay in place rather than slide out
    of view.
  * Hide non-matching search results.
  * Enable "next-match", "previous-match" and "activate" signals
    for search.
  * Match search term anywhere in family name.
  * Ensure "C" locale is used when saving double values to
    configuration files.
* Mon Oct 15 2018 Kyrill Detinov <lazy.kent@opensuse.org>
- Update to 0.7.3.1.
  * Fixes build failures with Vala versions newer than 0.34.
- Drop font-manager-fix_vala.patch: fixed upstream.
* Wed Apr 11 2018 lazy.kent@opensuse.org
- Update to 0.7.3.
- Drop all old patches.
- Add font-manager-fix_vala.patch: fix build with vala >= 0.35
  (fixed in git).
- Correct build and runtime dependencies.
- Correct URLs.
* Wed Nov 28 2012 lazy.kent@opensuse.org
- Get back intltool to build dependencies (need to regenerate
  translations).
* Fri Nov 16 2012 lazy.kent@opensuse.org
- Disable bytecode compile in configure. Use %%py_compile macro. So
  no need to delete *.pyo files that causes build fail for Factory
  (oS 12.3). Also doesn't require fdupes.
- Correct build dependencies:
  * remove autoconf, automake, fdupes, intltool, libtool;
  * pkgconfig -> pkg-config;
  * add pkgconfig(pangoft2).
- Add font-manager-0.5.7-russian.patch: update Russian translation.
* Sat Jun 23 2012 lazy.kent@opensuse.org
- Add font-manager-0.5.7-gcc47.patch from Debian project: fix build
  with GCC 4.7.
- License: GPL-3.0+.
- Use pkgconfig(*) as build dependencies.
- Split off language package.
- Clean up spec.
* Tue Dec 20 2011 pascal.bleser@opensuse.org
- remove dependency on python-sqlite2, not needed -- bnc#737900
* Thu Dec 23 2010 pascal.bleser@opensuse.org
- enable experimental I18N support
- update to 0.5.7:
  * allow sorting families by right-clicking
  * address an issue where selecting a collection causes unintended drag and drop effect
  * dd font version field to the font information dialog
  * allow managing collections while in "Browse" mode
  * enable browse mode by default
  * allow re-ordering while in compare mode
  * add family type filter to advanced search dialog; this uses Panose values and won't display fonts which don't supply them
  * use images which are friendlier to dark backgrounds.
  * fix some i18n related bugs
* Mon Aug  9 2010 pascal.bleser@opensuse.org
- update to 0.5.6:
  * fix issue where our window is still displayed at startup even though both minimize on startup and minimize to tray are enabled
  * fix issue where failure to load a font file causes startup to abort with a useless error message
  * automatically try to move any customizations found in ~/.fonts.conf to ~/.config/font-manager/local.conf instead of simply overwriting them -- you should still edit local.conf directly and not rely on this
  * browse mode now displays disabled fonts and uses the same size setting as the rest of the application, it also includes a size slider
  * added a dialog which allows mass renaming and deletion of files in imported folders; this has to be enabled in the preferences dialog
* Tue Jun 29 2010 pascal.bleser@opensuse.org
- update to 0.5.5:
  * fix issue where fontconfig/pango updates cause previews to stop displaying properly for disabled families
  * fix issue where fonts from user configured folders which are not in the users home directory get placed into the System category
  * fix issue where fonts with family names containing non-ASCII characters are unusable -- if you experienced this, please reset the applications cache to remove outdated entries
  * add a fontconfig editor which allows users to configure settings for individual families and styles; <matrix> transformations are not supported
  * add an alias editor which allows users to configure font substitution
  * cut down on the number of events that require a restart
- changes from 0.5.4:
  * fix several bugs introduced in the 0.5.x releases, hopefully without introducing new ones
  * several interface improvements, the most important one being that the application now saves most of it's state when closed, i.e. window size, preview font size, compare colors, pane positions, etc.
  * added an option to keep the current collection focused when adding families to other collections as suggested at http://code.google.com/p/font-manager/issues/detail?id=18
  * added a "browser mode" as suggested at http://code.google.com/p/font-manager/issues/detail?id=19
  * switch to Mallard-based help, unfortunately this means users who do not have Yelp installed will not have access to it
* Wed Mar 10 2010 pascal.bleser@opensuse.org
- initial package
